@@ -19,43 +19,44 @@
 
 #include "xsetwacomadaptor.h"
 
-#include "logging.h"
-#include "xsetwacomproperty.h"
-#include "stringutils.h"
 #include "buttonshortcut.h"
+#include "logging.h"
 #include "screenrotation.h"
+#include "stringutils.h"
 #include "tabletarea.h"
+#include "xsetwacomproperty.h"
 
 #include <QProcess>
 #include <QRegularExpression>
 
 using namespace Wacom;
 
-namespace Wacom {
+namespace Wacom
+{
 class XsetwacomAdaptorPrivate
 {
-    public:
-        QMap<QString, QString> buttonMap;
-        QString                device;
+public:
+    QMap<QString, QString> buttonMap;
+    QString device;
 }; // CLASS
 } // NAMESPACE
 
-
-XsetwacomAdaptor::XsetwacomAdaptor(const QString& deviceName)
-    : PropertyAdaptor(nullptr), d_ptr(new XsetwacomAdaptorPrivate)
+XsetwacomAdaptor::XsetwacomAdaptor(const QString &deviceName)
+    : PropertyAdaptor(nullptr)
+    , d_ptr(new XsetwacomAdaptorPrivate)
 {
-    Q_D( XsetwacomAdaptor );
+    Q_D(XsetwacomAdaptor);
     d->device = deviceName;
 }
 
-
-XsetwacomAdaptor::XsetwacomAdaptor(const QString& deviceName, const QMap< QString, QString >& buttonMap)
-    : PropertyAdaptor(nullptr), d_ptr(new XsetwacomAdaptorPrivate)
+XsetwacomAdaptor::XsetwacomAdaptor(const QString &deviceName, const QMap<QString, QString> &buttonMap)
+    : PropertyAdaptor(nullptr)
+    , d_ptr(new XsetwacomAdaptorPrivate)
 {
-    Q_D( XsetwacomAdaptor );
+    Q_D(XsetwacomAdaptor);
 
     d->buttonMap = buttonMap;
-    d->device    = deviceName;
+    d->device = deviceName;
 }
 
 XsetwacomAdaptor::~XsetwacomAdaptor()
@@ -63,16 +64,14 @@ XsetwacomAdaptor::~XsetwacomAdaptor()
     delete this->d_ptr;
 }
 
-
-const QList< Property > XsetwacomAdaptor::getProperties() const
+const QList<Property> XsetwacomAdaptor::getProperties() const
 {
     return XsetwacomProperty::ids();
 }
 
-
-const QString XsetwacomAdaptor::getProperty(const Property& property) const
+const QString XsetwacomAdaptor::getProperty(const Property &property) const
 {
-    Q_D( const XsetwacomAdaptor );
+    Q_D(const XsetwacomAdaptor);
 
     const XsetwacomProperty *xsetproperty = XsetwacomProperty::map(property);
 
@@ -83,28 +82,30 @@ const QString XsetwacomAdaptor::getProperty(const Property& property) const
 
     // TODO: get invert scroll parameter
 
-    QString convertedParam = convertParameter (*xsetproperty);
-    QString xsetwacomValue = getParameter (d->device, convertedParam);
+    QString convertedParam = convertParameter(*xsetproperty);
+    QString xsetwacomValue = getParameter(d->device, convertedParam);
 
     // convert value to a unified format
-    convertFromXsetwacomValue (*xsetproperty, xsetwacomValue);
+    convertFromXsetwacomValue(*xsetproperty, xsetwacomValue);
 
     qCDebug(KDED) << QString::fromLatin1("Reading property '%1' from device '%2' -> '%3'.").arg(property.key()).arg(d->device).arg(xsetwacomValue);
 
     return xsetwacomValue;
 }
 
-
-bool XsetwacomAdaptor::setProperty(const Property& property, const QString& value)
+bool XsetwacomAdaptor::setProperty(const Property &property, const QString &value)
 {
-    Q_D( const XsetwacomAdaptor );
+    Q_D(const XsetwacomAdaptor);
 
     qCDebug(KDED) << QString::fromLatin1("Setting property '%1' to '%2' on device '%3'.").arg(property.key()).arg(value).arg(d->device);
 
     const XsetwacomProperty *xsetproperty = XsetwacomProperty::map(property);
 
     if (!xsetproperty) {
-        qCWarning(KDED) << QString::fromLatin1("Can not set unsupported property '%1' to '%2' on device '%3' using xsetwacom!").arg(property.key()).arg(value).arg(d->device);
+        qCWarning(KDED) << QString::fromLatin1("Can not set unsupported property '%1' to '%2' on device '%3' using xsetwacom!")
+                               .arg(property.key())
+                               .arg(value)
+                               .arg(d->device);
         return false;
     }
 
@@ -112,7 +113,7 @@ bool XsetwacomAdaptor::setProperty(const Property& property, const QString& valu
     if (property == Property::Area) {
         return setArea(value);
 
-    }else if (property == Property::Rotate) {
+    } else if (property == Property::Rotate) {
         return setRotation(value);
 
     } else {
@@ -127,17 +128,14 @@ bool XsetwacomAdaptor::setProperty(const Property& property, const QString& valu
     return false;
 }
 
-
-bool XsetwacomAdaptor::supportsProperty(const Property& property) const
+bool XsetwacomAdaptor::supportsProperty(const Property &property) const
 {
     return (XsetwacomProperty::map(property) != nullptr);
 }
 
-
-
-const QString XsetwacomAdaptor::convertParameter(const XsetwacomProperty& param) const
+const QString XsetwacomAdaptor::convertParameter(const XsetwacomProperty &param) const
 {
-    Q_D( const XsetwacomAdaptor );
+    Q_D(const XsetwacomAdaptor);
 
     QString modifiedParam = param.key();
 
@@ -167,8 +165,7 @@ const QString XsetwacomAdaptor::convertParameter(const XsetwacomProperty& param)
     return modifiedParam;
 }
 
-
-void XsetwacomAdaptor::convertButtonShortcut (const XsetwacomProperty& property, QString& value) const
+void XsetwacomAdaptor::convertButtonShortcut(const XsetwacomProperty &property, QString &value) const
 {
     static const QRegularExpression rx(QLatin1String("^Button\\s*[0-9]+$"), QRegularExpression::CaseInsensitiveOption);
 
@@ -180,17 +177,13 @@ void XsetwacomAdaptor::convertButtonShortcut (const XsetwacomProperty& property,
     }
 }
 
-
-
-void XsetwacomAdaptor::convertFromXsetwacomValue(const XsetwacomProperty& property, QString& value) const
+void XsetwacomAdaptor::convertFromXsetwacomValue(const XsetwacomProperty &property, QString &value) const
 {
     // convert button shortcuts to a unified format
     convertButtonShortcut(property, value);
 }
 
-
-
-void XsetwacomAdaptor::convertToXsetwacomValue(const XsetwacomProperty& property, QString& value) const
+void XsetwacomAdaptor::convertToXsetwacomValue(const XsetwacomProperty &property, QString &value) const
 {
     // convert button shortcuts to a unified format
     convertButtonShortcut(property, value);
@@ -208,31 +201,28 @@ const QString XsetwacomAdaptor::getParameter(const QString &device, const QStrin
     return result.remove(QLatin1Char('\n'));
 }
 
-bool XsetwacomAdaptor::setArea(const QString& value)
+bool XsetwacomAdaptor::setArea(const QString &value)
 {
-    Q_D( const XsetwacomAdaptor );
+    Q_D(const XsetwacomAdaptor);
 
     TabletArea area(value);
 
-    if ( area.isEmpty() ) {
+    if (area.isEmpty()) {
         return setParameter(d->device, XsetwacomProperty::ResetArea.key(), QString());
     }
 
     return setParameter(d->device, XsetwacomProperty::Area.key(), area.toString());
 }
 
-
-
-bool XsetwacomAdaptor::setRotation(const QString& value)
+bool XsetwacomAdaptor::setRotation(const QString &value)
 {
-    Q_D( const XsetwacomAdaptor );
+    Q_D(const XsetwacomAdaptor);
 
-    const ScreenRotation* lookup   = ScreenRotation::find(value);
-    ScreenRotation        rotation = lookup ? *lookup : ScreenRotation::NONE;
+    const ScreenRotation *lookup = ScreenRotation::find(value);
+    ScreenRotation rotation = lookup ? *lookup : ScreenRotation::NONE;
 
     // only accept real rotations
-    if (rotation == ScreenRotation::NONE || rotation == ScreenRotation::CW ||
-        rotation == ScreenRotation::CCW  || rotation == ScreenRotation::HALF) {
+    if (rotation == ScreenRotation::NONE || rotation == ScreenRotation::CW || rotation == ScreenRotation::CCW || rotation == ScreenRotation::HALF) {
         setParameter(d->device, XsetwacomProperty::Rotate.key(), rotation.key());
         return true;
     }
